//XNAAnimSprite.cs
//
//XNA Animated Sprite Class
//
//Part of Spengler
//A 2D Platform Engine using XNA
//
//Created 5 March 2007
//
//By Gavin Cox
//
//Copyright  2007 All Rights Reserved

using System;
using System.Collections.Generic;
using System.Text;
using Microsoft.Xna.Framework;
using Microsoft.Xna.Framework.Graphics;
using Microsoft.Xna.Framework.Content;

namespace Spengler
{
    public class Frame
    {
        public Rectangle rect;
    }

    public class Sequence
    {
        public Frame[] frame;
		public int delay;
    }

    public class XNAAnimSprite : XNASprite
    {
        //--- Constants ---


		//--- Variables ---
		protected Sequence[] anim;      //Animation Sequences
		protected int current_anim;		//Current Animation
		protected int current_frame;    //Current Frame
		double lasttime;

        //--- Constructor ---
		public XNAAnimSprite(XNAGraphics xnagraphics, String filename)
            :base(xnagraphics, filename)
		{
			//xnag = xnagraphics;
			//tex = xnagraphics.content.Load<Texture2D>(filename);
            
            //Load File
			//---- TEMP CODE ----
			anim = new Sequence[1];
			anim[0] = new Sequence();
			anim[0].delay = 50;
			anim[0].frame = new Frame[4];
			for (int i = 0; i < 4; i++)
			{
				anim[0].frame[i] = new Frame();
				anim[0].frame[i].rect = new Rectangle((i * 64), 0, 64, 64);
			}			
			//---- END TEMP CODE ----

			current_anim = 0;
			current_frame = 0;

			lasttime = 0;
		}

        //--- Methods ---
        //Draw
        public override void Draw(Vector2 position)
        {
            base.Draw(position, anim[current_anim].frame[current_frame].rect);
        }

		//Next Frame
		public void NextFrame()
		{
			if (current_frame < anim[current_anim].frame.Length - 1)
			{
				current_frame++;
			}
			else
			{
				current_frame = 0;
			}
		}

		//Next Frame Delay
		public void NextFrameDelay(GameTime time)
		{
			if ((time.TotalGameTime.TotalMilliseconds - lasttime) > anim[current_anim].delay)
			{
				if (current_frame < anim[current_anim].frame.Length - 1)
				{
					current_frame++;
				}
				else
				{
					current_frame = 0;
				}

				lasttime = time.TotalGameTime.TotalMilliseconds;
			}
		}

        //- Get / Set Methods -
		//Current Animation
        public int CurrentAnim
        {
            get
            {
                return current_anim;
            }

            set
            {
				if ((value >= 0) || (value < anim.Length))
				{
					current_anim = value;
				}
            }
        }

		//Current Frame
		public int CurrentFrame
		{
			get
			{
				return current_frame;
			}

			set
			{
				if ((value >= 0) || (value < anim[current_anim].frame.Length))
				{
					current_frame = value;
				}
			}
		}
    }
}
